==> rhymix-2.1.28.zip: rhymix/modules/board/lang/zh-CN.php <==
<?php
$lang->board = '版面';
$lang->except_notice = '公告选项';
$lang->use_bottom_list = '显示列表';
$lang->customize_bottom_list = '列表设置';
$lang->use_anonymous = '使用匿名';
$lang->anonymous_name = '匿名昵称';
$lang->cmd_manage_menu = '菜单管理';
$lang->list_target_item = '备选项';
$lang->list_display_item = '显示项';
$lang->summary = '简要';
$lang->thumbnail = '缩略图';
$lang->last_post = '最后更新';
$lang->board_management = '管理版面';
$lang->search_result = '搜索结果';
$lang->consultation = '咨询功能';
$lang->secret = '密帖';
$lang->thisissecret = '此为密帖。';
$lang->admin_mail = '管理员电子邮件';
$lang->update_log = '修改历史';
$lang->last_updater = '更新';
$lang->cmd_board_list = '版面目录';
$lang->cmd_module_config = '版面共同设置';
$lang->cmd_board_info = '版面信息';
$lang->cmd_list_setting = '列表设置';
$lang->cmd_list_items = '显示列表及顺序';
$lang->cmd_create_board = '创建版面';
$lang->cmd_manage_selected_board = '管理选择的版面';
$lang->about_layout_setup = '可直接编辑博客布局代码。可以把控件代码插入到您喜欢的位置。';
$lang->about_board_category = '可以添加/删除分类项 分类有异常情况时，可以尝试重新生成缓冲文件。';
$lang->about_except_notice = '设置公告目录项不再重复显示到普通目录当中。';
$lang->about_use_bottom_list = '内容下面显示列表.';
$lang->about_customize_bottom_list = '帖子多的话 列表消耗服务器资源<br />如果不需要可以关闭 减少服务器负载<br />不影响搜索结果.';
$lang->about_use_anonymous_part1 = '删除发布者信息后引导匿名使用板块。';
$lang->about_use_anonymous_part2 = 'skin设置里隐藏发帖者信息的更有用。<br>高级设置中开启历史版本功能的话修改内容的时候会显示作者。';
$lang->about_anonymous_name = '使用匿名功能可以设置匿名昵称。<br><b>使用$NUM</b>的话可以给每个会员赋予num数。 (例: 匿名_$NUM → 匿名_12345678)<br>使用<b>$DAILYNUM</b>的话每天的nam数会变， <b>使用$DOCNUM</b>的话每个内容都变化。<br><b>使用$DOCDAILYNUM</b>的话每个内容每天变化。';
$lang->about_board = '可生成及管理版面的模块。';
$lang->about_consultation = '咨询功能是指除有管理权限的会员以外，其他会员只能浏览自己发表的主题。使用咨询功能时系统将自动禁止非会员的发表主题权限。';
$lang->about_secret = '设置主题及评论当中使用密帖与否。';
$lang->about_admin_mail = '有新的主题或评论时，将自动发电子邮件来通知管理员。 多数电子邮件由逗号(,)来分隔。';
$lang->about_list_config = '设置使用目录型目录页面时要显示的项目。 前提是使用的皮肤也支持此功能。 添加/删除项目，双击备选项/显示项即可。';
$lang->about_use_status = '发帖的时候选择状态、';
$lang->about_protect_comment = '回复里有他人回复的时候无法修改和删除、';
$lang->about_update_log = '修改帖子的时候 保存修改历史。';
$lang->skip_bottom_list_for_olddoc = '访问发布很长时间的内容时不计算全部列表';
$lang->skip_bottom_list_for_robot = '蜘蛛来访时候不计算全部列表';
$lang->msg_not_enough_point = '很遗憾！您的积分不够。';
$lang->write_comment = '回复';
$lang->msg_not_allow_comment = '本帖禁止回复';
$lang->no_board_instance = '没有生成的板块。';
$lang->choose_board_instance = '选择要管理的板块。';
$lang->comment_status = '回复';
$lang->category_settings = '设置分类';
$lang->hide_category = '隐藏分类';
$lang->about_hide_category = '临时不选择分类。';
$lang->allow_no_category = '允许不选择分类';
$lang->about_allow_no_category = '允许未选择分类的帖子。';
$lang->protect_content = '保护帖子功能';
$lang->protect_comment = '保护回复功能';
$lang->protect_regdate = '时间限制功能';
$lang->cancel_vote = '允许取消 推荐/非推荐/举报';
$lang->filter_specialchars = '禁止使用特殊符号';
$lang->document_length_limit = '限制帖子内容长度';
$lang->comment_length_limit = '限制回复内容长度';
$lang->about_document_length_limit = '禁止发布太多文字的帖子。';
$lang->about_comment_length_limit = '禁止发布太多文字的回复。';
$lang->update_order_on_comment = '发布回复的时候更新修改时间';
$lang->about_update_order_on_comment = '有回复的话更新帖子的时间，论坛形式里需要使用此功能。';
$lang->non_login_vote = '允许非会员推荐';
$lang->about_cancel_vote = '可以取消推荐 非推荐及举报。';
$lang->about_filter_specialchars = '禁止使用影响阅读的内容的符号。';
$lang->about_non_login_vote = '非会员也可以推荐。';
$lang->about_protect_regdate = '发布帖子或回复过一定时间的话无法修改或删除。（单位：天）';
$lang->about_protect_content = '无法删除或修改有回复的帖子。';
$lang->msg_protect_delete_content = '无法删除有回复的帖子。';
$lang->msg_protect_update_content = '无法修改有回复的帖子。';
$lang->msg_admin_document_no_modify = '无法修改管理员的帖子。';
$lang->msg_admin_comment_no_modify = '无法修改管理员的回复。';
$lang->msg_board_delete_protect_comment = '回复里有他人回复的时候无法删除。';
$lang->msg_board_update_protect_comment = '回复里有他人回复的时候无法修改。';
$lang->msg_protect_regdate_document = '过%d日的帖无法修改或删除。';
$lang->msg_protect_regdate_comment = '过%d日的回复无法修改或删除。';
$lang->msg_dont_have_update_log = '没有更新日志的帖子。';
$lang->msg_content_too_long = '内容太长。';
$lang->original_letter = '原帖';
$lang->msg_warning_update_log = '<span class="x_label x_label-important">注意！</span> 使用的话数据库会变大。';
$lang->reason_update = '修改理由';
$lang->msg_no_update_id = '修改原始号码是必选项。';
$lang->msg_no_update_log = '没有修改日志。';
$lang->cmd_modify_by_update_log = '使这个日志修改帖子';
$lang->msg_admin_update_log = '管理员修改过的帖子，请咨询管理员。';
$lang->msg_update_log_revert = '确定需要还原这个版本吗?';
$lang->write_admin = '管理员发布';
$lang->revert_reason_update = '还原到这个版本';
$lang->document_force_to_move = '删除时使用回收站';
$lang->about_document_force_to_move = '删除帖子时候把帖子移动到回收站。';
$lang->comment_delete_message = '留出回复空间';
$lang->about_comment_delete_message = '删除回复的时候不完全删除，代替显示"删除的回复"。';
$lang->cmd_only_p_comment = '只有在回复里有他人回复的时候保留';
$lang->cmd_all_comment_message = '在所有回复中保留';
$lang->cmd_do_not_message = '不留';
$lang->delete_placeholder = '完全删除';
$lang->msg_document_notify_mail = '[%s] 发布了新的帖子 : %s';
$lang->cmd_document_vote_user = '本帖的推荐人目录';
$lang->cmd_comment_vote_user = '显示回复的推荐人';
$lang->msg_not_target = '只能查询文件或回复的推荐人目录。.';
$lang->cmd_board_combined_board = '聚合板块';
$lang->about_board_combined_board = '可以聚合其他板块的内容查看，按crtl选择多个板块。';
$lang->cmd_board_include_modules = '选择要包含的板块';
$lang->cmd_board_include_modules_none = '(不包含)';

==> rhymix-2.1.31.zip: rhymix/modules/board/lang/zh-CN.php <==
<?php
$lang->board = '版面';
$lang->except_notice = '公告选项';
$lang->use_bottom_list = '显示列表';
$lang->customize_bottom_list = '列表设置';
$lang->use_anonymous = '使用匿名';
$lang->anonymous_name = '匿名昵称';
$lang->cmd_manage_menu = '菜单管理';
$lang->list_target_item = '备选项';
$lang->list_display_item = '显示项';
$lang->summary = '简要';
$lang->thumbnail = '缩略图';
$lang->last_post = '最后更新';
$lang->board_management = '管理版面';
$lang->search_result = '搜索结果';
$lang->consultation = '咨询功能';
$lang->secret = '密帖';
$lang->thisissecret = '此为密帖。';
$lang->admin_mail = '管理员电子邮件';
$lang->update_log = '修改历史';
$lang->last_updater = '更新';
$lang->cmd_board_list = '版面目录';
$lang->cmd_module_config = '版面共同设置';
$lang->cmd_board_info = '版面信息';
$lang->cmd_list_setting = '列表设置';
$lang->cmd_list_items = '显示列表及顺序';
$lang->cmd_create_board = '创建版面';
$lang->cmd_manage_selected_board = '管理选择的版面';
$lang->about_layout_setup = '可直接编辑博客布局代码。可以把控件代码插入到您喜欢的位置。';
$lang->about_board_category = '可以添加/删除分类项 分类有异常情况时，可以尝试重新生成缓冲文件。';
$lang->about_except_notice = '设置公告目录项不再重复显示到普通目录当中。';
$lang->about_use_bottom_list = '内容下面显示列表.';
$lang->about_customize_bottom_list = '帖子多的话 列表消耗服务器资源<br />如果不需要可以关闭 减少服务器负载<br />不影响搜索结果.';
$lang->about_use_anonymous_part1 = '删除发布者信息后引导匿名使用板块。';
$lang->about_use_anonymous_part2 = 'skin设置里隐藏发帖者信息的更有用。<br>高级设置中开启历史版本功能的话修改内容的时候会显示作者。';
$lang->about_anonymous_name = '使用匿名功能可以设置匿名昵称。<br><b>使用$NUM</b>的话可以给每个会员赋予num数。 (例: 匿名_$NUM → 匿名_12345678)<br>使用<b>$DAILYNUM</b>的话每天的nam数会变， <b>使用$DOCNUM</b>的话每个内容都变化。<br><b>使用$DOCDAILYNUM</b>的话每个内容每天变化。';
$lang->about_board = '可生成及管理版面的模块。';
$lang->about_consultation = '咨询功能是指除有管理权限的会员以外，其他会员只能浏览自己发表的主题。使用咨询功能时系统将自动禁止非会员的发表主题权限。';
$lang->about_secret = '设置主题及评论当中使用密帖与否。';
$lang->about_admin_mail = '有新的主题或评论时，将自动发电子邮件来通知管理员。 多数电子邮件由逗号(,)来分隔。';
$lang->about_list_config = '设置使用目录型目录页面时要显示的项目。 前提是使用的皮肤也支持此功能。 添加/删除项目，双击备选项/显示项即可。';
$lang->about_use_status = '发帖的时候选择状态、';
$lang->about_protect_comment = '回复里有他人回复的时候无法修改和删除、';
$lang->about_update_log = '修改帖子的时候 保存修改历史。';
$lang->skip_bottom_list_for_olddoc = '访问发布很长时间的内容时不计算全部列表';
$lang->skip_bottom_list_for_robot = '蜘蛛来访时候不计算全部列表';
$lang->msg_not_enough_point = '很遗憾！您的积分不够。';
$lang->write_comment = '回复';
$lang->msg_not_allow_comment = '本帖禁止回复';
$lang->no_board_instance = '没有生成的板块。';
$lang->choose_board_instance = '选择要管理的板块。';
$lang->comment_status = '回复';
$lang->category_settings = '设置分类';
$lang->hide_category = '隐藏分类';
$lang->about_hide_category = '临时不选择分类。';
$lang->allow_no_category = '允许不选择分类';
$lang->about_allow_no_category = '允许未选择分类的帖子。';
$lang->protect_content = '保护帖子功能';
$lang->protect_comment = '保护回复功能';
$lang->protect_regdate = '时间限制功能';
$lang->cancel_vote = '允许取消 推荐/非推荐/举报';
$lang->filter_specialchars = '禁止使用特殊符号';
$lang->document_length_limit = '限制帖子内容长度';
$lang->comment_length_limit = '限制回复内容长度';
$lang->about_document_length_limit = '禁止发布太多文字的帖子。';
$lang->about_comment_length_limit = '禁止发布太多文字的回复。';
$lang->update_order_on_comment = '发布回复的时候更新修改时间';
$lang->about_update_order_on_comment = '有回复的话更新帖子的时间，论坛形式里需要使用此功能。';
$lang->non_login_vote = '允许非会员推荐';
$lang->about_cancel_vote = '可以取消推荐 非推荐及举报。';
$lang->about_filter_specialchars = '禁止使用影响阅读的内容的符号。';
$lang->about_non_login_vote = '非会员也可以推荐。';
$lang->about_protect_regdate = '发布帖子或回复过一定时间的话无法修改或删除。（单位：天）';
$lang->about_protect_content = '无法删除或修改有回复的帖子。';
$lang->msg_protect_delete_content = '评论数超过 %d 条的帖子无法删除。';
$lang->msg_protect_update_content = '评论数超过 %d 条的帖子无法编辑。';
$lang->msg_admin_document_no_modify = '无法修改管理员的帖子。';
$lang->msg_admin_comment_no_modify = '无法修改管理员的回复。';
$lang->msg_board_delete_protect_comment = '回复里有他人回复的时候无法删除。';
$lang->msg_board_update_protect_comment = '回复里有他人回复的时候无法修改。';
$lang->msg_protect_regdate_document = '过%d日的帖无法修改或删除。';
$lang->msg_protect_regdate_comment = '过%d日的回复无法修改或删除。';
$lang->msg_dont_have_update_log = '没有更新日志的帖子。';
$lang->msg_content_too_long = '内容太长。';
$lang->original_letter = '原帖';
$lang->msg_warning_update_log = '<span class="x_label x_label-important">注意！</span> 使用的话数据库会变大。';
$lang->reason_update = '修改理由';
$lang->msg_no_update_id = '修改原始号码是必选项。';
$lang->msg_no_update_log = '没有修改日志。';
$lang->cmd_modify_by_update_log = '使这个日志修改帖子';
$lang->msg_admin_update_log = '管理员修改过的帖子，请咨询管理员。';
$lang->msg_update_log_revert = '确定需要还原这个版本吗?';
$lang->write_admin = '管理员发布';
$lang->revert_reason_update = '还原到这个版本';
$lang->document_force_to_move = '删除时使用回收站';
$lang->about_document_force_to_move = '删除帖子时候把帖子移动到回收站。';
$lang->comment_delete_message = '留出回复空间';
$lang->about_comment_delete_message = '删除回复的时候不完全删除，代替显示"删除的回复"。';
$lang->cmd_only_p_comment = '只有在回复里有他人回复的时候保留';
$lang->cmd_all_comment_message = '在所有回复中保留';
$lang->cmd_do_not_message = '不留';
$lang->delete_placeholder = '完全删除';
$lang->msg_document_notify_mail = '[%s] 发布了新的帖子 : %s';
$lang->cmd_document_vote_user = '本帖的推荐人目录';
$lang->cmd_comment_vote_user = '显示回复的推荐人';
$lang->msg_not_target = '只能查询文件或回复的推荐人目录。.';
$lang->cmd_board_combined_board = '聚合板块';
$lang->about_board_combined_board = '可以聚合其他板块的内容查看，按crtl选择多个板块。';
$lang->cmd_board_include_modules = '选择要包含的板块';
$lang->cmd_board_include_modules_none = '(不包含)';
